==> anjuta-2.1.3.tar.bz2: anjuta-2.1.3/libanjuta/libanjuta.h <==
/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 4; tab-width: 4 -*- */
/*
 * libanjuta.h
 * Copyright (C) Naba Kumar  <naba@gnome.org>
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
#ifndef LIBANJUTA_H
#define LIBANJUTA_H

/* FIXME: Update required */
#include <libanjuta/anjuta-children.h>
#include <libanjuta/anjuta-debug.h>
#include <libanjuta/anjuta-encodings.h>
#include <libanjuta/anjuta-enum-types.h>
#include <libanjuta/anjuta-launcher.h>
#include <libanjuta/anjuta-marshal.h>
#include <libanjuta/anjuta-plugin-description.h>
#include <libanjuta/anjuta-plugin.h>
#include <libanjuta/anjuta-plugin-handle.h>
#include <libanjuta/anjuta-plugin-manager.h>
#include <libanjuta/anjuta-preferences-dialog.h>
#include <libanjuta/anjuta-preferences.h>
#include <libanjuta/anjuta-profile.h>
#include <libanjuta/anjuta-profile-manager.h>
#include <libanjuta/anjuta-save-prompt.h>
#include <libanjuta/anjuta-serializer.h>
#include <libanjuta/anjuta-session.h>
#include <libanjuta/anjuta-shell.h>
#include <libanjuta/anjuta-status.h>
#include <libanjuta/anjuta-ui.h>
#include <libanjuta/anjuta-utils.h>
#include <libanjuta/resources.h>

#endif

==> anjuta-2.3.2.tar.bz2: anjuta-2.3.2/libanjuta/libanjuta.h <==
/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 4; tab-width: 4 -*- */
/*
 * libanjuta.h
 * Copyright (C) Naba Kumar  <naba@gnome.org>
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
#ifndef LIBANJUTA_H
#define LIBANJUTA_H

/* FIXME: Update required */
#include <libanjuta/anjuta-debug.h>
#include <libanjuta/anjuta-encodings.h>
#include <libanjuta/anjuta-enum-types.h>
#include <libanjuta/anjuta-launcher.h>
#include <libanjuta/anjuta-marshal.h>
#include <libanjuta/anjuta-plugin-description.h>
#include <libanjuta/anjuta-plugin.h>
#include <libanjuta/anjuta-plugin-manager.h>
#include <libanjuta/anjuta-plugin-handle.h>
#include <libanjuta/anjuta-preferences-dialog.h>
#include <libanjuta/anjuta-preferences.h>
#include <libanjuta/anjuta-profile.h>
#include <libanjuta/anjuta-profile-manager.h>
#include <libanjuta/anjuta-save-prompt.h>
#include <libanjuta/anjuta-serializer.h>
#include <libanjuta/anjuta-session.h>
#include <libanjuta/anjuta-shell.h>
#include <libanjuta/anjuta-status.h>
#include <libanjuta/anjuta-ui.h>
#include <libanjuta/anjuta-utils.h>
#include <libanjuta/resources.h>
#include <libanjuta/anjuta-vcs-status-tree-view.h>
#include <libanjuta/anjuta-command.h>
#include <libanjuta/anjuta-async-command.h>

#endif
